package org.acme.mqtt;

import java.util.Random;
import java.util.concurrent.TimeUnit;

import javax.enterprise.context.ApplicationScoped;

import org.eclipse.microprofile.reactive.messaging.Outgoing;

import io.reactivex.Flowable;

/**
 * A bean producing random prices every 5 seconds.
 * The prices are written to a MQTT topic (prices). The MQTT configuration is specified in the application configuration.
 */
@ApplicationScoped
public class PriceGenerator {

    private Random random = new Random();

    @Outgoing("topic-price")
    public Flowable<MqttMessage<String>> generate() {
        return Flowable.interval(1, TimeUnit.SECONDS)
                .map(tick -> {
                    int price = random.nextInt(100);
                    System.out.println("Sending price: " + price);
//                    return Integer.toString(price);
                    return MqttMessage.of(Integer.toString(price));
                });
    }

}
